@@ -2,7 +2,7 @@
 
 /*
     NUT nutrition software 
-    Copyright (C) 1996-2010 by Jim Jozwiak.
+    Copyright (C) 1996-2014 by Jim Jozwiak.
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
 #ifndef RECMEAL_H
@@ -29,6 +29,8 @@ extern "C" {
 void record_meals(void);
 void today(char *);
 void time_machine(char *);
+int reverse_time_machine(char *);
+void today_plus(char *, int *);
 
 #ifdef __cplusplus
 } /* closing brace for extern "C" */
